@@ -149,7 +149,7 @@ setup_sigsegv_handler (void) {
 
 static void
 dump_struct_data (FILE * fp, GLog * glog, int pid) {
-  fprintf (fp, "==%d== FILE: %s\n", pid, glog->filename);
+  fprintf (fp, "==%d== FILE: %s\n", pid, glog->props.filename);
   fprintf (fp, "==%d== Line number: %" PRIu64 "\n", pid, glog->processed);
   fprintf (fp, "==%d== Invalid data: %" PRIu64 "\n", pid, glog->invalid);
   fprintf (fp, "==%d== Piping: %d\n", pid, glog->piping);
