@@ -6,7 +6,7 @@
  * \____/\____/_/  |_\___/\___/\___/____/____/
  *
  * The MIT License (MIT)
- * Copyright (c) 2009-2022 Gerardo Orellana <hello @ goaccess.io>
+ * Copyright (c) 2009-2023 Gerardo Orellana <hello @ goaccess.io>
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to deal
@@ -33,33 +33,8 @@
 #include "commons.h"
 #include "parser.h"
 
-/* Total number of storage metrics (GSMetric) */
-#define GSMTRC_TOTAL 19
 #define DB_PATH "/tmp"
 
-/* Enumerated Storage Metrics */
-typedef enum GSMetric_ {
-  MTRC_KEYMAP,
-  MTRC_ROOTMAP,
-  MTRC_DATAMAP,
-  MTRC_UNIQMAP,
-  MTRC_ROOT,
-  MTRC_HITS,
-  MTRC_VISITORS,
-  MTRC_BW,
-  MTRC_CUMTS,
-  MTRC_MAXTS,
-  MTRC_METHODS,
-  MTRC_PROTOCOLS,
-  MTRC_AGENTS,
-  MTRC_METADATA,
-  MTRC_UNIQUE_KEYS,
-  MTRC_AGENT_KEYS,
-  MTRC_AGENT_VALS,
-  MTRC_CNT_VALID,
-  MTRC_CNT_BW,
-} GSMetric;
-
 #define GAMTRC_TOTAL 8
 /* Enumerated App Metrics */
 typedef enum GAMetric_ {
